@@ -24,7 +24,7 @@ import (
 )
 
 const (
-	Version  = "1.5.0"
+	Version  = "1.6.0"
 	Warranty = `Copyright (C) 2020-2021 Sergey Matveev
 
 This program is free software: you can redistribute it and/or modify
@@ -99,13 +99,17 @@ List all currently known source files.`
 		d = `Usage: redo-ood [target ...]
 
 List all currently known out-of-date targets.`
+	case "redo-affects":
+		d = `Usage: redo-affects target [...]
+
+List all targets that will be affected by changing the specified ones.`
 	default:
 		d = `Usage: goredo -symlinks
 
 goredo expects to be called through the symbolic link to it.
-Available commands: redo, redo-always, redo-cleanup, redo-dot,
-redo-ifchange, redo-ifcreate, redo-log, redo-ood, redo-sources,
-redo-stamp, redo-targets, redo-whichdo.`
+Available commands: redo, redo-affects, redo-always, redo-cleanup,
+redo-dot, redo-ifchange, redo-ifcreate, redo-log, redo-ood,
+redo-sources, redo-stamp, redo-targets, redo-whichdo.`
 	}
 	fmt.Fprintf(os.Stderr, "%s\n\nCommon options:\n", d)
 	flag.PrintDefaults()
